extern "C" {
#include <tcl.h>
#ifdef USE_PTHREADS
#include <pthread.h>
#endif
}
#include <iostream.h>

#include "tclmidi.h"

#ifndef TCL_7_3
int
main(int argc, char **argv)
{

	Tcl_Main(argc, argv, Tcl_AppInit);
	return (0);
}
#endif

int
Tcl_AppInit(Tcl_Interp *interp)
{

	if (Tcl_Init(interp) != TCL_OK)
		return (TCL_ERROR);
	return (Tclm_Init(interp));
}
